# pyOCD Documentation


## Table of Contents

### User documentation

#### Introduction

- [Terminology](terminology.md)
- [Target support](target_support.md)
- [Configuration](configuration.md)
- [Available options](options.md)
- [User scripts](user_scripts.md)

#### Advanced

- [Configuring logging](configuring_logging.md)
- [Debugging multicore devices](multicore_debug.md)
- [Target security features](security.md)

#### Python API
- [Introduction to the pyOCD Python API](python_api.md)
- [Python API examples](api_examples.md)

#### Miscellaneous
- [Installing on non-x86 platforms](installing_on_non_x86.md)

### Developer documentation

- [Developers’ guide](developers_guide.md)
- [Architecture overview](architecture.md)
- [How to add new targets](adding_new_targets.md)
- [Building a standalone gdb server executable](how_to_build.md)
- [Running the automated tests](automated_tests.md)





